==> haskell-yesod-persistent-1.4.3-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.3
id: yesod-persistent-1.4.3-JB9q3R2u3LoDKDnZ0fjU82
key: yesod-persistent-1.4.3-JB9q3R2u3LoDKDnZ0fjU82
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
abi: 689195d374d79d62a360c3fefab67098
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-persistent-1.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-persistent-1.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/yesod-persistent-1.4.3
hs-libraries: HSyesod-persistent-1.4.3-JB9q3R2u3LoDKDnZ0fjU82
depends:
    base-4.10.1.0 yesod-core-1.4.37.2-AjTvrktJbhi4X3iRhum4cu
    persistent-2.7.1-4AZD96eQWrPFdUYc2aQXji
    persistent-template-2.5.3-72EHfVi2wTyCODiO1VnwMW
    transformers-0.5.2.0 blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
    conduit-1.2.12.1-BcLGeTf7mkLAqHbUwhBWCt
    resourcet-1.1.10-9ZnD9eSbn8b2f4IrDnWp0t
    resource-pool-0.2.3.2-8yJF1X1mblX7cZeK83igwg
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             yesod-core-1.4.37.2-AjTvrktJbhi4X3iRhum4cu=c590e4e7f056bdfe029518064cf3184f
             persistent-2.7.1-4AZD96eQWrPFdUYc2aQXji=a92af6dfe7a8d802b6a3c1aef7f72585
             persistent-template-2.5.3-72EHfVi2wTyCODiO1VnwMW=149bdf4ed19afade09dce0f72a1ec9a3
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=efe227a7a23c0583e6a2d74f96c7367f
             conduit-1.2.12.1-BcLGeTf7mkLAqHbUwhBWCt=a60b40003bb55bfd70329e4276f55f11
             resourcet-1.1.10-9ZnD9eSbn8b2f4IrDnWp0t=297a88691064799df02cb2935dc973fc
             resource-pool-0.2.3.2-8yJF1X1mblX7cZeK83igwg=03f4157c9d6de44b7ea839ba61d14b45
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.4.3-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.3
id: yesod-persistent-1.4.3-DIb5aMnXF3zHFaGblypwBz
key: yesod-persistent-1.4.3-DIb5aMnXF3zHFaGblypwBz
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
abi: f3668c6e0af657870bcf577b39614b9e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-persistent-1.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-persistent-1.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/yesod-persistent-1.4.3
hs-libraries: HSyesod-persistent-1.4.3-DIb5aMnXF3zHFaGblypwBz
depends:
    base-4.10.1.0 yesod-core-1.4.37.2-EKva0lQERHz5DhqI5v1a4
    persistent-2.7.3-3hcKqcfzBz13ycUyEJJW9C
    persistent-template-2.5.3-4HToX2NozFFFktDysElttF
    transformers-0.5.2.0 blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
    conduit-1.2.12.1-BcLGeTf7mkLAqHbUwhBWCt
    resourcet-1.1.10-9ZnD9eSbn8b2f4IrDnWp0t
    resource-pool-0.2.3.2-8yJF1X1mblX7cZeK83igwg
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             yesod-core-1.4.37.2-EKva0lQERHz5DhqI5v1a4=236e11cd0081a7eb7bcbb26d9284563f
             persistent-2.7.3-3hcKqcfzBz13ycUyEJJW9C=dacce763658025c8396df479d81de512
             persistent-template-2.5.3-4HToX2NozFFFktDysElttF=09778ef6c84ed90233006033cfcd79e3
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=efe227a7a23c0583e6a2d74f96c7367f
             conduit-1.2.12.1-BcLGeTf7mkLAqHbUwhBWCt=a60b40003bb55bfd70329e4276f55f11
             resourcet-1.1.10-9ZnD9eSbn8b2f4IrDnWp0t=297a88691064799df02cb2935dc973fc
             resource-pool-0.2.3.2-8yJF1X1mblX7cZeK83igwg=03f4157c9d6de44b7ea839ba61d14b45
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
